@@ -12,6 +12,7 @@ container object.
     guarantees are made yet). The public API in
     `prompt_toolkit.shortcuts.dialogs` on the other hand is considered stable.
 """
+
 from __future__ import annotations
 
 from functools import partial
@@ -58,9 +59,8 @@ from prompt_toolkit.layout.controls import (
     FormattedTextControl,
     GetLinePrefixCallable,
 )
-from prompt_toolkit.layout.dimension import AnyDimension
+from prompt_toolkit.layout.dimension import AnyDimension, to_dimension
 from prompt_toolkit.layout.dimension import Dimension as D
-from prompt_toolkit.layout.dimension import to_dimension
 from prompt_toolkit.layout.margins import (
     ConditionalMargin,
     NumberedMargin,
@@ -100,6 +100,7 @@ E = KeyPressEvent
 
 class Border:
     "Box drawing characters. (Thin)"
+
     HORIZONTAL = "\u2500"
     VERTICAL = "\u2502"
     TOP_LEFT = "\u250c"
